@@ -5,7 +5,7 @@ import pandas as pd
 import datetime
 from scipy.linalg import block_diag
 from typing import Any, Tuple
-from checkpython321.checkpython321.datainterface import GNSSData, SARData
+from checkpython321.datainterface import GNSSData, SARData
 
 
 class DataIntegration:
